@@ -1,7 +1,7 @@
 package Yars::Client;
 
 # ABSTRACT: Yet Another RESTful-Archive Service Client
-our $VERSION = '0.85'; # VERSION
+our $VERSION = '0.86'; # VERSION
 
 use strict;
 use warnings;
@@ -59,7 +59,11 @@ sub new {
     my $self = shift->SUPER::new(@_);
     $self->client->max_redirects(30);
     if($Mojolicious::VERSION < 4.0) {
-        Mojo::IOLoop::Stream->timeout(600);
+        # if Mojolicious.pm isn't loaded then we can't
+        # detect the version, so wrap this call in an
+        # eval since it will fail on newer mojos
+        eval { Mojo::IOLoop::Stream->timeout(600) }
+        # ignore the error.
     }
     $self->client->connect_timeout(30);
     return $self;
@@ -424,7 +428,7 @@ Yars::Client - Yet Another RESTful-Archive Service Client
 
 =head1 VERSION
 
-version 0.85
+version 0.86
 
 =head1 SYNOPSIS
 
